#include "ServoMotorComponent.h"

ServoMotorComponent::ServoMotorComponent(int PIN,  unsigned long updatePeriod) {
    this->PIN = PIN;
    this->myservo.attach(PIN);
    this->desiredposition = Position::MIDDLE;
    this->currentPosition = 0;
    this->lastUpTime = millis();
    this->updatePeriod = updatePeriod;
}

int ServoMotorComponent::getCurrentPosition() {
    return this->myservo.read(this->PIN);
}

void ServoMotorComponent::setCurrentPosition() {
    this->currentPosition = this->myservo.read(this->PIN);
}

void ServoMotorComponent::setDesiredPosition(Position desiredPosition) {
    switch (desiredPosition) {
        case Position::LEFT:
            this->desiredposition = 52;
            break;
        case Position::MIDDLE:
            this->desiredposition = 32;
            break;
        case Position::RIGHT:
            this->desiredposition = 18;
            break;
        default:
            break;
    }
}


void ServoMotorComponent::refresh() {
    if (this->desiredposition == this->currentPosition 
    ||  millis() - this->lastUpTime <= this->updatePeriod) return;

    if (this->currentPosition > this->desiredposition) {
        this->currentPosition--;
    }
    if (this->currentPosition < this->desiredposition) {
        this->currentPosition++;
    }
    this->lastUpTime = millis();
    this->myservo.write(this->PIN, this->currentPosition);
}


void ServoMotorComponent::setPin(int PIN) {
    this->PIN = PIN;
    this->myservo.attach(PIN);
    return;
}